#
# spec file for package deepin-music-player
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2013-2018 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           deepin-music-player
Version:        3.1.7.2
Release:        lp150.4.3.1
Summary:        Deepin Music Player
License:        GPL-3.0+
Group:          Productivity/Multimedia/Sound/Players
Url:            https://github.com/linuxdeepin/deepin-music
Source0:        https://github.com/linuxdeepin/deepin-music/archive/%{version}/deepin-music-%{version}.tar.gz
# Fix boo#1131464
Source1:        %{name}-rpmlintrc
BuildRequires:  QtAV-devel
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Network-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  libqt5-qtmultimedia-devel
BuildRequires:  libqt5-qtsvg-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  python
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dtkcore)
BuildRequires:  pkgconfig(dtksettings)
BuildRequires:  pkgconfig(dtksettingsview)
BuildRequires:  pkgconfig(dtkwidget)
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcue)
BuildRequires:  pkgconfig(taglib)
# produce png icons from svg
BuildRequires:  rsvg-view
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Deepin Music Player is a music player backed by gstreamer, with
customizable UI, and featuring music search by Pinyin and Quanpin. It
supports colorful lyrics, online audio support and a "mini mode".

%package -n libdmusic1
Summary:        Libraries for Deepin Music Player
Group:          System/Libraries

%description -n libdmusic1
This package contains the main implementation of the Deepin Music
Player.

%package -n deepin-music-libnetease-meta-search
Summary:        Libnetease integration for the Deepin Music Player
Group:          Productivity/Multimedia/Sound/Players

%description -n deepin-music-libnetease-meta-search
This package contains the libnetease plugin for searches with the
Deepin Music Player searches.

%package -n libdbusextended-qt5-1
Summary:        D-Bus system for the Deepin Music Player
Group:          System/Libraries

%description -n libdbusextended-qt5-1
Deepin Music Player with brilliant and tweakful UI Deepin-UI based,
gstreamer front-end, with features likes search music by pinyin,
quanpin, colorful lyrics supports, and more powerful functions
you will found.

The libdbusextended-qt5 is the Dbus system libraries for
Deepin Music Player.

%package -n libmpris-qt5-1
Summary:        MPRI system for the Deepin Music Player
Group:          System/Libraries

%description -n libmpris-qt5-1
The MPRI system library for Deepin Music Player.

%package -n libdbusextended-qt5-devel
Summary:        Development files for the Deepin Music Player D-Bus system
Group:          Development/Libraries/C and C++
Requires:       libdbusextended-qt5-1 = %{version}-%{release}

%description -n libdbusextended-qt5-devel
The libdbusextended-devel package contains the header files and developer
docs for libdbusextended.

%package -n libmpris-qt5-devel
Summary:        Development files for the Deepin Music Player MPRI library
Group:          Development/Libraries/C and C++
Requires:       libmpris-qt5-1 = %{version}-%{release}

%description -n libmpris-qt5-devel
The libmpris-devel package contains the header files and developer
docs for libmpris.

%prep
%setup -q -n deepin-music-%{version}
sed -i 's|lrelease|lrelease-qt5|g' tool/translate_generation.*
sed -i '/%1/s|lib|%{_lib}|' music-player/core/pluginmanager.cpp
sed -i '/target.path/s|lib|%{_lib}|' libdmusic/libdmusic.pro \
plugin/netease-meta-search/netease-meta-search.pro
# fix the non-standard unity stuff, anyway we will not use it.
# appending -x
sed -i 's/^\[\([^D].*$\)/\[X-\1/' music-player/data/deepin-music.desktop
# replace [[:space:]] with '-'
sed -i 's/ Shortcut /-Shortcut-/' music-player/data/deepin-music.desktop

%build
%qmake5 DEFINES+=QT_NO_DEBUG_OUTPUT \
        PREFIX=%{_prefix} \
        LIB_INSTALL_DIR=%{_libdir} \
        LIBSUFFIX=%{lib}
make %{?_smp_mflags}

%install
%qmake5_install

%ifnarch i386 i486 i586 i686 athlon %{arm}
    mv %{buildroot}%{_libexecdir}/*.so* %{buildroot}%{_libdir}
    mv %{buildroot}%{_libexecdir}/pkgconfig %{buildroot}%{_libdir}/pkgconfig
    rm -rf %{buildroot}%{_libexecdir}
%endif

# Remove invalid developement files.
rm -rf %{buildroot}%{_libdir}/libdmusic.so

# produce png icons from svg
for i in 16 24 32 48 64 96 128 256; do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps
  rsvg-convert -h $i -w $i \
    %{buildroot}%{_datadir}/dman/deepin-music/common/deepin-music.svg \
    -o %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/deepin-music.png
done

%suse_update_desktop_file -r deepin-music Player AudioVideo
%fdupes %{buildroot}%{_prefix}

%post
%icon_theme_cache_postun
%desktop_database_postun

%postun
%icon_theme_cache_postun
%desktop_database_postun

%post -n libdmusic1 -p /sbin/ldconfig

%postun -n libdmusic1 -p /sbin/ldconfig

%post -n libdbusextended-qt5-1 -p /sbin/ldconfig

%postun -n libdbusextended-qt5-1 -p /sbin/ldconfig

%post -n libmpris-qt5-1 -p /sbin/ldconfig

%postun -n libmpris-qt5-1 -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING CHANGELOG.md README.md TODO
%{_bindir}/deepin-music
%{_datadir}/applications/deepin-music.desktop
%{_datadir}/dbus-1/services/com.deepin.dde.music.service
%{_datadir}/deepin-music
%{_datadir}/dman
%{_datadir}/icons/hicolor/*/apps/deepin-music.png
%{_datadir}/icons/hicolor/scalable/apps/deepin-music.svg

%files -n libdmusic1
%defattr(-,root,root,-)
%{_libdir}/libdmusic.so.*

%files -n deepin-music-libnetease-meta-search
%defattr(-,root,root,-)
%dir %{_libdir}/deepin-music
%dir %{_libdir}/deepin-music/plugins
%{_libdir}/deepin-music/plugins/libnetease-meta-search.so.*
%{_libdir}/deepin-music/plugins/libnetease-meta-search.so

%files -n libdbusextended-qt5-1
%defattr(-,root,root,-)
%{_libdir}/libdbusextended-qt5.so.*

%files -n libmpris-qt5-1
%defattr(-,root,root,-)
%{_libdir}/libmpris-qt5.so.*

%files -n libdbusextended-qt5-devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/dbusextended-qt5.pc
%{_libdir}/libdbusextended-qt5.so
%{_includedir}/DBusExtended

%files -n libmpris-qt5-devel
%defattr(-,root,root,-)
%{_libdir}/pkgconfig/mpris-qt5.pc
%{_libdir}/libmpris-qt5.so
%dir %{_libdir}/qt5/
%dir %{_libdir}/qt5/mkspecs/
%dir %{_libdir}/qt5/mkspecs/features/
%{_libdir}/qt5/mkspecs/features/mpris-qt5.prf
%{_includedir}/MprisQt/

%changelog
* Wed Apr  3 2019 Hillwood Yang <hillwood@opensuse.org>
- Fix lyrics don't work (boo#1131464).
  * Add libnetease-meta-search.so in filelist, it is not a developement file
  * Add deepin-music-player-rpmlintrc
* Fri Mar 23 2018 kasimir_@outlook.de
- Fix build in armv6l
* Fri Feb  9 2018 hillwood@opensuse.org
- Fix build for Leap 15.0
  * Set BuildRequires tag for python.
* Fri Nov 24 2017 hillwood@opensuse.org
- Update 3.1.7.2
  * Fix showNormal not work (bb22dc99)
  * Fix crash when selectNext on qt 5.9 (bed9d856)
  * Fix hidpi playing state (84783418)
  * Fix lyric text cut (1dbf4dc2)
  * Fix move qmediaplayer to main thread (3ce0ca3c)
  * Fix dialog style (cfc0db93)
  * Use deviceRatio in musicitemdelegate (f3a65085)
  * Enable drag progress bar (22f8916e)
  * Fix border pos (6fa9cc9e)
  * Set dialog flag error (ef200472)
  * Change footer bar cover mouse cursor (a4837dce)
  * Fix libdmusic install path (2d86199a)
  * Make dropdown show full text on ru locale (fcc58c97)
  * Stop next after continue error count >= 5 (e6127596)
  * Call dbus trash (b5d6fcb4)
  * Extern footer progress (3459625e)
  * All use svg (a942c308)
  * Use dbus call filemanager (e276e636)
  * Remove dtk2 workaround (0eb1ee32)
  * Use dtk DWaterProgress (6109ffee)
  * Add hidpi support (107e5987)
- Drop deepin-tool-kit
- Drop libdui
* Thu Sep 28 2017 hillwood@opensuse.org
- Fix build in armv7l.
* Wed Sep 27 2017 hillwood@opensuse.org
- Update to 3.1.6
  * Update deepin-tool-kit
  * Use QtAV
  * Use dtkwidget
  * Use libcue
- Drop deepin-music-dui.patch, merged by upstream.
* Wed Mar 15 2017 i@marguerite.su
- Fix capitalized Summary
- Use 'rsvg-view' to produce multi-sized png icons from svg
  resource
- Fix the Unity play indicator groups in deepin-music.desktop
* Sun Feb 19 2017 jengelh@inai.de
- Replace totally useless description.
- Rename deepin-music-libnetease-meta-search1 again:
  it is a plugin, not a standard library!
- Fix RPM group selection. Do not call fdupes on root.
- Qt5 mkspecs belong into -devel subpackage.
* Sat Feb 18 2017 hillwood@opensuse.org
- Rename libnetease-meta-search as deepin-music-libnetease-meta-search1.
- Drop two devel packages.
* Thu Feb 16 2017 hillwood@opensuse.org
- Update to 3.0.1, fix boo#1023777.
  * Port python to C++ and QT5.
  * Port GStreamer to QT5Multimedia.
- add deepin-music-dui.patch.
  * Add lost pkgconfig item.
* Thu Nov 12 2015 hillwood@linuxfans.org
- Fix boo#954761
  * add python-Pillow as Requires.
- Add %%icon_theme_cache_post / %%icon_theme_cache_postun macro.
* Thu Jul 16 2015 i@marguerite.su
- update verison 2.90.0+git20150617.bb7889c
  * no upstream changelog
- clean specfile
  * upstream url: github.com/linuxdeepin/deepin-music
  * use upstream source instead of deepin distro's
  * avoid holding /usr/share/icons/hicolor
  * other minor fixes
* Tue Feb 17 2015 hillwood@linuxfans.org
- Update to 2.0git20150204.
  * add installation script
- remove deepin-music-player.desktop and deepin-music-player.png,
  upstream have included it.
* Sun Jul  6 2014 hillwood@linuxfans.org
- Add python-gstreamer-0_10 as Requires.
* Mon May 26 2014 hillwood@linuxfans.org
- Update to 2.0git20140505.
  Feature update.
* Thu Aug 15 2013 hillwood@linuxfans.org
- add deepin-gsettings as Requires
* Wed Aug 14 2013 hillwood@linuxfans.org
- update to 2.0git20130802
  * upsteam did not provide changlog
* Mon Apr 29 2013 hillwood@linuxfans.org
- update to 1.0.1git20130330(2.0 Alpha)
  * fix bugs
* Tue Mar 19 2013 douglarek@outlook.com
- Bug fix
  * fix bnc#808258
* Sun Feb 24 2013 kaji331@hotmail.com
- fix require python-cddb to python-CDDB
* Wed Feb  6 2013 hillwood@linuxfans.org
- update to 1.0.1git20130125(2.0 Alpha)
  * add plugins support
  * add mini mode
  * more media formats support
* Tue Jan  8 2013 douglarek@outlook.com
- Add runtime dependence: python-gtk
* Wed Sep 26 2012 hillwood@linuxfans.org
- update to 1.0.1git20120911
- fix bnc#778659
- more changlog please see http://goo.gl/WCVGo
* Tue Sep  4 2012 hillwood@linuxfans.org
- license update: GPL-3.0+
* Tue Sep  4 2012 hillwood@linuxfans.org
- add python-chardet , python-imaging and python-xlib as require
  packages.
* Sun Sep  2 2012 hillwood@linuxfans.org
- Initial package 1.0git20120716
  Init.
  Implement logging to tracking events that happen.
  Implement a basic configuration.
  Use listen-music-player play kernel, and thank him for his.
  Determine the Audio file type is supported.
  Add Universal encoding detector of the chardet.
